"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _crypto = _interopRequireDefault(require("crypto"));

var _path = _interopRequireDefault(require("path"));

var _postcss = _interopRequireDefault(require("postcss"));

var _requestPromise = _interopRequireDefault(require("request-promise"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const urlReg = /url\(('|")?((?:http|\/\/)(?:[^"']+))(\1)\)/;

const getDeclUrl = value => {
  const url = value.match(urlReg)[2];

  const md5 = _crypto.default.createHash('md5');

  const urlIdentity = md5.update(url).digest('hex');
  return {
    urlIdentity,
    url
  };
};

var _default = _postcss.default.plugin('postcss-assets', ({
  outputOptions,
  options
}, opts = {}) => {
  // 所有 css 中的网络请求
  const networkRequestMap = {};
  return root => {
    return new Promise(resolve => {
      // 字体文件
      root.walkAtRules(atrule => {
        atrule.walkDecls(decl => {
          if (decl.prop == 'src') {
            decl.value.split(',').forEach(value => {
              if (urlReg.test(value)) {
                const _getDeclUrl = getDeclUrl(value),
                      url = _getDeclUrl.url,
                      urlIdentity = _getDeclUrl.urlIdentity;

                networkRequestMap[urlIdentity] = {
                  url,
                  decl
                };
              }
            });
          }
        });
      }); // 常规 css

      root.walkRules(rule => {
        rule.walkDecls(decl => {
          if (decl.prop == 'background-image' || decl.prop == 'background') {
            if (urlReg.test(decl.value)) {
              const _getDeclUrl2 = getDeclUrl(decl.value),
                    url = _getDeclUrl2.url,
                    urlIdentity = _getDeclUrl2.urlIdentity;

              networkRequestMap[urlIdentity] = {
                url,
                decl
              };
            }
          }
        });
      });

      if (Object.keys(networkRequestMap).length > 0) {
        Promise.all(Object.entries(networkRequestMap).map(([key, networkRequest]) => {
          const originUrl = networkRequest.url;
          const url = originUrl.startsWith('http') ? originUrl : `http:${originUrl}`;
          return _requestPromise.default.get({
            url,
            encoding: null
          }).then(res => {
            const buffer = Buffer.from(res, 'utf-8');

            const ext = _path.default.extname(url);

            const md5 = _crypto.default.createHash('md5');

            const basename = md5.update(buffer).digest('hex') + ext;

            const outputPath = _path.default.join(outputOptions.publicPath || '', options.outputPath, basename);

            const asset = {
              contents: buffer,
              path: outputPath,
              basename
            };
            networkRequestMap[key] = asset;
            opts.emit(asset);
            return Promise.resolve(asset);
          });
        })).then(() => {
          // 字体文件
          root.walkAtRules(atrule => {
            atrule.walkDecls(decl => {
              if (decl.prop == 'src') {
                const newValue = decl.value.split(',').map(value => {
                  if (urlReg.test(value)) {
                    const _getDeclUrl3 = getDeclUrl(value),
                          urlIdentity = _getDeclUrl3.urlIdentity;

                    return value.replace(urlReg, () => {
                      return `url('${networkRequestMap[urlIdentity].path}')`;
                    });
                  }

                  return value;
                }).join(',');
                decl.value = newValue;
              }
            });
          }); // 常规 css

          root.walkRules(rule => {
            rule.walkDecls(decl => {
              if (decl.prop == 'background-image' || decl.prop == 'background') {
                if (urlReg.test(decl.value)) {
                  const _getDeclUrl4 = getDeclUrl(decl.value),
                        urlIdentity = _getDeclUrl4.urlIdentity;

                  decl.value = decl.value.replace(urlReg, () => {
                    return `url('${networkRequestMap[urlIdentity].path}')`;
                  });
                }
              }
            });
          });
          resolve();
        });
      } else {
        resolve();
      }
    });
  };
});

exports.default = _default;